.. image:: https://s.weblate.org/cdn/Logo-Darktext-borders.png
   :alt: Weblate
   :target: https://weblate.org/
   :height: 80px

**Weblate is a copylefted libre software web-based continuous localization system,
used by over 2500 libre projects and companies in more than 165 countries.**

This module contains schemas used in Weblate exports.

.. image:: https://img.shields.io/badge/website-weblate.org-blue.svg
    :alt: Website
    :target: https://weblate.org/

.. image:: https://hosted.weblate.org/widgets/weblate/-/svg-badge.svg
    :alt: Translation status
    :target: https://hosted.weblate.org/engage/weblate/?utm_source=widget

.. image:: https://bestpractices.coreinfrastructure.org/projects/552/badge
    :alt: CII Best Practices
    :target: https://bestpractices.coreinfrastructure.org/projects/552

.. image:: https://img.shields.io/pypi/v/weblate_schemas.svg
    :target: https://pypi.org/project/weblate_schemas/
    :alt: PyPI package

.. image:: https://img.shields.io/readthedocs/weblate.svg
    :alt: Documentation
    :target: https://docs.weblate.org/en/latest/schemas.html

Installation
------------

Install using pip:

.. code-block:: sh

    pip3 install weblate_schemas

Sources are available at <https://github.com/WeblateOrg/weblate_schemas>.
